Module parser

Module parser 

Enums

Msh2Section
MshError
MshVersion

Functions

end_of_line
format_footer
format_header
msh2_ascii_header
msh4_ascii_header
msh_header
parse_msh_file
Returns a vector of meshes, since two or more concatenated msh files are also a valid msh file.
parse_single_msh
sp
tab
whitespace

Type Aliases

MshResult